summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-06 19:45:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-06 19:45:01 -0600
commitfb7e279ef21733ca91caad571e63263b1f947f85 (patch)
treecd03e2405d1f6eddd9fd50d4a29faa6d4b990796
parent18896070bf8c173783628a31da969042bddd2867 (diff)
downloadtdebindings-fb7e279ef21733ca91caad571e63263b1f947f85.tar.gz
tdebindings-fb7e279ef21733ca91caad571e63263b1f947f85.zip
Rename KCmd to avoid conflicts with KDE4
-rw-r--r--dcoppython/test/dcopserver/main.cpp2
-rw-r--r--kalyptus/kalyptusCxxToJNI.pm12
-rw-r--r--kalyptus/kalyptusCxxToJava.pm8
-rw-r--r--kalyptus/kalyptusCxxToKimono.pm8
-rw-r--r--kalyptus/kalyptusCxxToSmoke.pm2
-rw-r--r--kdejava/koala/kdejava/KDESupport.cpp8
-rw-r--r--kdejava/koala/kdejava/KDESupport.h4
-rw-r--r--kdejava/koala/kdejava/TDECmdLineArgs.cpp12
-rw-r--r--kdejava/koala/org/kde/koala/TDECmdLineArgs.java2
-rw-r--r--kjsembed/kjscmd.cpp2
-rw-r--r--korundum/rubylib/korundum/kdehandlers.cpp8
-rw-r--r--korundum/rubylib/rbtdeconfig_compiler/rbtdeconfig_compiler.cpp4
12 files changed, 36 insertions, 36 deletions
diff --git a/dcoppython/test/dcopserver/main.cpp b/dcoppython/test/dcopserver/main.cpp
index 4d6bcb8b..aad9030c 100644
--- a/dcoppython/test/dcopserver/main.cpp
+++ b/dcoppython/test/dcopserver/main.cpp
@@ -13,7 +13,7 @@ static const char *description =
static const char *version = "0.1";
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
{
// { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
{ 0, 0, 0 }
diff --git a/kalyptus/kalyptusCxxToJNI.pm b/kalyptus/kalyptusCxxToJNI.pm
index d400ef93..a5b603e9 100644
--- a/kalyptus/kalyptusCxxToJNI.pm
+++ b/kalyptus/kalyptusCxxToJNI.pm
@@ -1815,7 +1815,7 @@ sub cplusplusToJava
return "double[]";
} elsif ( kalyptusDataDict::ctypemap($cplusplusType) =~ /^\s*(unsigned )?short\s*\*/ ) {
return "short[]";
- } elsif ( $cplusplusType =~ /KCmdLineOptions/ ) {
+ } elsif ( $cplusplusType =~ /TDECmdLineOptions/ ) {
return "String[][]";
} elsif ( $cplusplusType =~ /char\s*\*\*/ || $cplusplusType =~ /TQStringList/|| $cplusplusType =~ /TQStrList/) {
return "String[]";
@@ -2066,8 +2066,8 @@ sub jniArgTocplusplus
}
}
} elsif ( $javaType =~ /String\[\]\[\]/ ) {
- if ( $cplusplusType =~ /KCmdLineOptions/ ) {
- $jniArg = "(KCmdLineOptions*) KDESupport::toKCmdLineOptions(env, $argName)";
+ if ( $cplusplusType =~ /TDECmdLineOptions/ ) {
+ $jniArg = "(TDECmdLineOptions*) KDESupport::toTDECmdLineOptions(env, $argName)";
}
} elsif ( $javaType =~ /String\[\]/ ) {
if ( $cplusplusType =~ /TQStringList/ ) {
@@ -5466,8 +5466,8 @@ sub printJavadocComment($$$$)
$line =~ s/TQString::null/null/g;
$line =~ s/(const )?QC?String(\s*&)?/String/g;
$line =~ s/TQByteArray/byte[]/g;
- $line =~ s/(const )?KCmdLineOptions\s*(\w+)\[\]/String[][] $2/;
- $line =~ s/KCmdLineLastOption//g;
+ $line =~ s/(const )?TDECmdLineOptions\s*(\w+)\[\]/String[][] $2/;
+ $line =~ s/TDECmdLineLastOption//g;
$line =~ s/virtual //g;
$line =~ s/~\w+\(\)((\s*{\s*})|;)//g;
$line =~ s/0L/null/g;
@@ -5572,7 +5572,7 @@ sub printJavadocComment($$$$)
$returntext =~ s/TQStringList/ArrayList/g;
$returntext =~ s/([Aa]) ArrayList/$1n ArrayList/g;
$returntext =~ s/TQString/String/g;
- $returntext =~ s/KCmdLineOptions/String[][]/;
+ $returntext =~ s/TDECmdLineOptions/String[][]/;
$returntext =~ s!\\note!<b>Note:<\b>!g;
$returntext =~ s!\\(code|verbatim)!<pre>!g;
$returntext =~ s!\\(endcode|endverbatim)!</pre>!g;
diff --git a/kalyptus/kalyptusCxxToJava.pm b/kalyptus/kalyptusCxxToJava.pm
index 866295c3..fc932e54 100644
--- a/kalyptus/kalyptusCxxToJava.pm
+++ b/kalyptus/kalyptusCxxToJava.pm
@@ -549,7 +549,7 @@ sub cplusplusToJava
return "double[]";
} elsif ( kalyptusDataDict::ctypemap($cplusplusType) =~ /^\s*(unsigned )?short\s*\*/ ) {
return "short[]";
- } elsif ( $cplusplusType =~ /KCmdLineOptions/ ) {
+ } elsif ( $cplusplusType =~ /TDECmdLineOptions/ ) {
return "String[][]";
} elsif ( $cplusplusType =~ /char\s*\*\*/ || $cplusplusType =~ /TQStringList/|| $cplusplusType =~ /TQStrList/) {
return "String[]";
@@ -3305,8 +3305,8 @@ sub printJavadocComment($$$$)
$line =~ s/TQString::null/null/g;
$line =~ s/(const )?QC?String(\s*&)?/String/g;
$line =~ s/TQByteArray/byte[]/g;
- $line =~ s/(const )?KCmdLineOptions\s*(\w+)\[\]/String[][] $2/;
- $line =~ s/KCmdLineLastOption//g;
+ $line =~ s/(const )?TDECmdLineOptions\s*(\w+)\[\]/String[][] $2/;
+ $line =~ s/TDECmdLineLastOption//g;
$line =~ s/virtual //g;
$line =~ s/~\w+\(\)((\s*{\s*})|;)//g;
$line =~ s/0L/null/g;
@@ -3411,7 +3411,7 @@ sub printJavadocComment($$$$)
$returntext =~ s/TQStringList/ArrayList/g;
$returntext =~ s/([Aa]) ArrayList/$1n ArrayList/g;
$returntext =~ s/TQString/String/g;
- $returntext =~ s/KCmdLineOptions/String[][]/;
+ $returntext =~ s/TDECmdLineOptions/String[][]/;
$returntext =~ s!\\note!<b>Note:<\b>!g;
$returntext =~ s!\\(code|verbatim)!<pre>!g;
$returntext =~ s!\\(endcode|endverbatim)!</pre>!g;
diff --git a/kalyptus/kalyptusCxxToKimono.pm b/kalyptus/kalyptusCxxToKimono.pm
index b328a53a..9848de34 100644
--- a/kalyptus/kalyptusCxxToKimono.pm
+++ b/kalyptus/kalyptusCxxToKimono.pm
@@ -545,7 +545,7 @@ sub cplusplusToCSharp
return "out double";
} elsif ( kalyptusDataDict::ctypemap($cplusplusType) =~ /^\s*(unsigned )?short\s*\*/ ) {
return "out short";
- } elsif ( $cplusplusType =~ /KCmdLineOptions/ ) {
+ } elsif ( $cplusplusType =~ /TDECmdLineOptions/ ) {
return "string[][]";
} elsif ( $cplusplusType =~ /char\s*\*\*/ || $cplusplusType =~ /TQStringList/|| $cplusplusType =~ /TQStrList/) {
return "string[]";
@@ -3498,8 +3498,8 @@ sub printCSharpdocComment($$$$)
$line =~ s/(const )?TQTime([^r])/DateTime$1/g;
$line =~ s/TQString::null/null/g;
$line =~ s/(const )?QC?String(\s*&)?/string/g;
- $line =~ s/(const )?KCmdLineOptions\s*(\w+)\[\]/string[][] $2/;
- $line =~ s/KCmdLineLastOption//g;
+ $line =~ s/(const )?TDECmdLineOptions\s*(\w+)\[\]/string[][] $2/;
+ $line =~ s/TDECmdLineLastOption//g;
$line =~ s/virtual //g;
$line =~ s/~\w+\(\)((\s*{\s*})|;)//g;
$line =~ s/0L/null/g;
@@ -3601,7 +3601,7 @@ sub printCSharpdocComment($$$$)
$returntext =~ s/TQStringList/ArrayList/g;
$returntext =~ s/([Aa]) ArrayList/$1n ArrayList/g;
$returntext =~ s/TQString/string/g;
- $returntext =~ s/KCmdLineOptions/string[][]/;
+ $returntext =~ s/TDECmdLineOptions/string[][]/;
$returntext =~ s!\\note!<b>Note:<\b>!g;
$returntext =~ s!\\(code|verbatim)!<pre>!g;
$returntext =~ s!\\(endcode|endverbatim)!</pre>!g;
diff --git a/kalyptus/kalyptusCxxToSmoke.pm b/kalyptus/kalyptusCxxToSmoke.pm
index 8485b636..f733da4d 100644
--- a/kalyptus/kalyptusCxxToSmoke.pm
+++ b/kalyptus/kalyptusCxxToSmoke.pm
@@ -329,7 +329,7 @@ sub preParseClass
$className eq 'TQWidgetList' ||
$className eq 'TQObjectList' ||
$className eq 'TQStrList' ||
- $className eq 'KCmdLineOptions' ||
+ $className eq 'TDECmdLineOptions' ||
# Those are template related
$className eq 'TQTSManip' || # cause compiler errors with several gcc versions
$className eq 'TQGDict' ||
diff --git a/kdejava/koala/kdejava/KDESupport.cpp b/kdejava/koala/kdejava/KDESupport.cpp
index 9c3059d1..ea0f9649 100644
--- a/kdejava/koala/kdejava/KDESupport.cpp
+++ b/kdejava/koala/kdejava/KDESupport.cpp
@@ -123,19 +123,19 @@ KDESupport::toKFileItemList(JNIEnv * env, jobjectArray itemList, KFileItemList *
return *kitemList;
}
-KCmdLineOptions *
-KDESupport::toKCmdLineOptions(JNIEnv * env, jobjectArray optionsArray)
+TDECmdLineOptions *
+KDESupport::toTDECmdLineOptions(JNIEnv * env, jobjectArray optionsArray)
{
jstring jstr;
const char * str;
int length;
int index;
jobjectArray optionEntry;
- KCmdLineOptions * cmdLineOptions;
+ TDECmdLineOptions * cmdLineOptions;
length = env->GetArrayLength(optionsArray);
// Allocate 'length + 1' entries, to include an all NULLs last entry
- cmdLineOptions = (KCmdLineOptions *) calloc(length + 1, sizeof(struct KCmdLineOptions));
+ cmdLineOptions = (TDECmdLineOptions *) calloc(length + 1, sizeof(struct TDECmdLineOptions));
for (index = 0; index < length; index++) {
optionEntry = (jobjectArray) env->GetObjectArrayElement(optionsArray, index);
diff --git a/kdejava/koala/kdejava/TDECmdLineArgs.cpp b/kdejava/koala/kdejava/TDECmdLineArgs.cpp
index 0cb06177..108c1595 100644
--- a/kdejava/koala/kdejava/TDECmdLineArgs.cpp
+++ b/kdejava/koala/kdejava/TDECmdLineArgs.cpp
@@ -13,14 +13,14 @@
class TDECmdLineArgsJBridge : public TDECmdLineArgs
{
public:
- TDECmdLineArgsJBridge(const KCmdLineOptions* arg1,const char* arg2,const char* arg3) : TDECmdLineArgs(arg1,arg2,arg3) {};
+ TDECmdLineArgsJBridge(const TDECmdLineOptions* arg1,const char* arg2,const char* arg3) : TDECmdLineArgs(arg1,arg2,arg3) {};
};
JNIEXPORT void JNICALL
Java_org_kde_koala_TDECmdLineArgs_addCmdLineOptions___3_3Ljava_lang_String_2(JNIEnv* env, jclass cls, jobjectArray options)
{
(void) cls;
- TDECmdLineArgsJBridge::addCmdLineOptions((KCmdLineOptions*) KDESupport::toKCmdLineOptions(env, options));
+ TDECmdLineArgsJBridge::addCmdLineOptions((TDECmdLineOptions*) KDESupport::toTDECmdLineOptions(env, options));
return;
}
@@ -29,7 +29,7 @@ Java_org_kde_koala_TDECmdLineArgs_addCmdLineOptions___3_3Ljava_lang_String_2Ljav
{
(void) cls;
static TQCString* _qstring_name = 0;
- TDECmdLineArgsJBridge::addCmdLineOptions((KCmdLineOptions*) KDESupport::toKCmdLineOptions(env, options), (const char*) QtSupport::toCharString(env, name, &_qstring_name));
+ TDECmdLineArgsJBridge::addCmdLineOptions((TDECmdLineOptions*) KDESupport::toTDECmdLineOptions(env, options), (const char*) QtSupport::toCharString(env, name, &_qstring_name));
return;
}
@@ -39,7 +39,7 @@ Java_org_kde_koala_TDECmdLineArgs_addCmdLineOptions___3_3Ljava_lang_String_2Ljav
(void) cls;
static TQCString* _qstring_name = 0;
static TQCString* _qstring_id = 0;
- TDECmdLineArgsJBridge::addCmdLineOptions((KCmdLineOptions*) KDESupport::toKCmdLineOptions(env, options), (const char*) QtSupport::toCharString(env, name, &_qstring_name), (const char*) QtSupport::toCharString(env, id, &_qstring_id));
+ TDECmdLineArgsJBridge::addCmdLineOptions((TDECmdLineOptions*) KDESupport::toTDECmdLineOptions(env, options), (const char*) QtSupport::toCharString(env, name, &_qstring_name), (const char*) QtSupport::toCharString(env, id, &_qstring_id));
return;
}
@@ -50,7 +50,7 @@ Java_org_kde_koala_TDECmdLineArgs_addCmdLineOptions___3_3Ljava_lang_String_2Ljav
static TQCString* _qstring_name = 0;
static TQCString* _qstring_id = 0;
static TQCString* _qstring_afterId = 0;
- TDECmdLineArgsJBridge::addCmdLineOptions((KCmdLineOptions*) KDESupport::toKCmdLineOptions(env, options), (const char*) QtSupport::toCharString(env, name, &_qstring_name), (const char*) QtSupport::toCharString(env, id, &_qstring_id), (const char*) QtSupport::toCharString(env, afterId, &_qstring_afterId));
+ TDECmdLineArgsJBridge::addCmdLineOptions((TDECmdLineOptions*) KDESupport::toTDECmdLineOptions(env, options), (const char*) QtSupport::toCharString(env, name, &_qstring_name), (const char*) QtSupport::toCharString(env, id, &_qstring_id), (const char*) QtSupport::toCharString(env, afterId, &_qstring_afterId));
return;
}
@@ -178,7 +178,7 @@ Java_org_kde_koala_TDECmdLineArgs_newTDECmdLineArgs(JNIEnv* env, jobject obj, jo
static TQCString* _qstring__name = 0;
static TQCString* _qstring__id = 0;
if (QtSupport::getQt(env, obj) == 0) {
- QtSupport::setQt(env, obj, new TDECmdLineArgsJBridge((KCmdLineOptions*) KDESupport::toKCmdLineOptions(env, _options), (const char*) QtSupport::toCharString(env, _name, &_qstring__name), (const char*) QtSupport::toCharString(env, _id, &_qstring__id)));
+ QtSupport::setQt(env, obj, new TDECmdLineArgsJBridge((TDECmdLineOptions*) KDESupport::toTDECmdLineOptions(env, _options), (const char*) QtSupport::toCharString(env, _name, &_qstring__name), (const char*) QtSupport::toCharString(env, _id, &_qstring__id)));
QtSupport::setObjectForQtKey(env, obj, QtSupport::getQt(env, obj));
}
return;
diff --git a/kdejava/koala/org/kde/koala/TDECmdLineArgs.java b/kdejava/koala/org/kde/koala/TDECmdLineArgs.java
index 423df7a3..ab44dba6 100644
--- a/kdejava/koala/org/kde/koala/TDECmdLineArgs.java
+++ b/kdejava/koala/org/kde/koala/TDECmdLineArgs.java
@@ -186,7 +186,7 @@ public class TDECmdLineArgs implements QtSupport {
not specifically turned off in the command line. Equivalently,
it will be false if the option was specifically turned off in
the command line, or if the option is turned off by default (in
- the KCmdLineOptions list) and was not specifically turned on in
+ the TDECmdLineOptions list) and was not specifically turned on in
the command line.
@short Read out a boolean option or check for the presence of string option.
diff --git a/kjsembed/kjscmd.cpp b/kjsembed/kjscmd.cpp
index 6161cad1..8b2b732b 100644
--- a/kjsembed/kjscmd.cpp
+++ b/kjsembed/kjscmd.cpp
@@ -39,7 +39,7 @@
#include "jsconsolewidget.h"
#include "jssecuritypolicy.h"
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
{
{ "c", 0, 0 },
{ "console", I18N_NOOP("Displays the KJSEmbed console"), 0 },
diff --git a/korundum/rubylib/korundum/kdehandlers.cpp b/korundum/rubylib/korundum/kdehandlers.cpp
index 7236fc9b..83db54cf 100644
--- a/korundum/rubylib/korundum/kdehandlers.cpp
+++ b/korundum/rubylib/korundum/kdehandlers.cpp
@@ -187,7 +187,7 @@ void marshall_TQCStringList(Marshall *m) {
# define BREAKPOINT { fprintf(stderr, "hit ctrl-c\n"); int b = 0; while (b == 0) { ; } }
#endif
-void marshall_KCmdLineOptions(Marshall *m) {
+void marshall_TDECmdLineOptions(Marshall *m) {
switch(m->action()) {
case Marshall::FromVALUE:
{
@@ -201,8 +201,8 @@ void marshall_KCmdLineOptions(Marshall *m) {
}
// Allocate 'length + 1' entries, to include an all NULLs last entry
- KCmdLineOptions *cmdLineOptions = (KCmdLineOptions *) calloc( RARRAY_LEN(optionslist) + 1,
- sizeof(struct KCmdLineOptions) );
+ TDECmdLineOptions *cmdLineOptions = (TDECmdLineOptions *) calloc( RARRAY_LEN(optionslist) + 1,
+ sizeof(struct TDECmdLineOptions) );
VALUE options;
long i;
@@ -1388,7 +1388,7 @@ void marshall_TQMapTQCStringDCOPRef(Marshall *m) {
TypeHandler KDE_handlers[] = {
{ "QCStringList", marshall_TQCStringList },
- { "KCmdLineOptions*", marshall_KCmdLineOptions },
+ { "TDECmdLineOptions*", marshall_TDECmdLineOptions },
{ "TDEActionPtrList", marshall_TDEActionList },
{ "TQPtrList<TDEAction>", marshall_TDEActionList },
{ "TQPtrList<TDEAction>&", marshall_TDEActionList },
diff --git a/korundum/rubylib/rbtdeconfig_compiler/rbtdeconfig_compiler.cpp b/korundum/rubylib/rbtdeconfig_compiler/rbtdeconfig_compiler.cpp
index 8db55019..ef923e71 100644
--- a/korundum/rubylib/rbtdeconfig_compiler/rbtdeconfig_compiler.cpp
+++ b/korundum/rubylib/rbtdeconfig_compiler/rbtdeconfig_compiler.cpp
@@ -39,13 +39,13 @@
#include <iostream>
-static const KCmdLineOptions options[] =
+static const TDECmdLineOptions options[] =
{
{ "d", 0, 0 },
{ "directory <dir>", I18N_NOOP("Directory to generate files in"), "." },
{ "+file.kcfg", I18N_NOOP("Input kcfg XML file"), 0 },
{ "+file.kcfgc", I18N_NOOP("Code generation options file"), 0 },
- KCmdLineLastOption
+ TDECmdLineLastOption
};
diff --git a/kdejava/koala/kdejava/KDESupport.h b/kdejava/koala/kdejava/KDESupport.h
index 8ecb47f0..6df03995 100644
--- a/kdejava/koala/kdejava/KDESupport.h
+++ b/kdejava/koala/kdejava/KDESupport.h
@@ -50,8 +50,8 @@ public:
/** Convert from a Java ArrayList to a KFileItemList */
static KFileItemList * toKFileItemList(JNIEnv * env, jobjectArray itemList, KFileItemList ** kitemList);
- /** Converts java options entries to the C++ KCmdLineOption equivalent */
- static KCmdLineOptions * toKCmdLineOptions(JNIEnv * env, jobjectArray optionsArray);
+ /** Converts java options entries to the C++ TDECmdLineOption equivalent */
+ static TDECmdLineOptions * toTDECmdLineOptions(JNIEnv * env, jobjectArray optionsArray);
/** Converts a java.io.ByteArrayOutputStream to a TQByteArray */
static TQByteArray * toTQByteArrayFromStream(JNIEnv * env, TQByteArray * byteArray, jobject byteStream);